import { TypedEmitter } from "tiny-typed-emitter";
import { HTTPApi } from "./api";
import { GuardMode, SupportedFeature } from "./types";
import { HubResponse } from "./models";
import { IndexedProperty, PropertyMetadataAny, PropertyValue, PropertyValues, RawValue, RawValues, StationEvents } from "./interfaces";
import { P2PConnectionType, WatermarkSetting1, WatermarkSetting2, WatermarkSetting3, WatermarkSetting4 } from "../p2p/types";
import { Device } from "./device";
import { PushMessage } from "../push/models";
export declare class Station extends TypedEmitter<StationEvents> {
    private api;
    private rawStation;
    private log;
    private dskKey;
    private dskExpiration;
    private p2pSession;
    private properties;
    private rawProperties;
    private ready;
    private currentDelay;
    private reconnectTimeout?;
    private p2pCurrentModeChanged;
    static readonly CHANNEL: number;
    constructor(api: HTTPApi, station: HubResponse);
    getStateID(state: string, level?: number): string;
    getStateChannel(): string;
    getRawStation(): HubResponse;
    update(station: HubResponse): void;
    private updateProperty;
    updateRawProperties(values: RawValues): void;
    updateRawProperty(type: number, value: RawValue): boolean;
    protected convertRawPropertyValue(property: PropertyMetadataAny, value: RawValue): PropertyValue;
    getPropertyMetadata(name: string): PropertyMetadataAny;
    getPropertyValue(name: string): PropertyValue;
    getRawProperty(type: number): RawValue;
    getRawProperties(): RawValues;
    getProperties(): PropertyValues;
    getPropertiesMetadata(): IndexedProperty;
    hasProperty(name: string): boolean;
    isStation(): boolean;
    isDeviceStation(): boolean;
    getDeviceType(): number;
    getHardwareVersion(): string;
    getMACAddress(): string;
    getModel(): string;
    getName(): string;
    getSerial(): string;
    getSoftwareVersion(): string;
    getIPAddress(): string;
    getLANIPAddress(): PropertyValue;
    getGuardMode(): PropertyValue;
    getCurrentMode(): PropertyValue;
    processPushNotification(message: PushMessage): void;
    private getDSKKeys;
    isConnected(): boolean;
    close(): void;
    connect(p2pConnectionType?: P2PConnectionType, quickStreamStart?: boolean): Promise<void>;
    private onFinishDownload;
    private onStartDownload;
    private onStopLivestream;
    private onStartLivestream;
    private onWifiRssiChanged;
    private onRTSPUrl;
    private onESLParameter;
    setGuardMode(mode: GuardMode): Promise<void>;
    getCameraInfo(): Promise<void>;
    getStorageInfo(): Promise<void>;
    private onAlarmMode;
    private _getDeviceSerial;
    private onCameraInfo;
    private onCommandResponse;
    private onConnect;
    private onDisconnect;
    private getCurrentDelay;
    private resetCurrentDelay;
    private scheduleReconnect;
    getSupportedFeatures(): Array<SupportedFeature>;
    isFeatureSupported(feature: SupportedFeature): boolean;
    rebootHUB(): Promise<void>;
    setStatusLed(device: Device, value: boolean): Promise<void>;
    setAutoNightVision(device: Device, value: boolean): Promise<void>;
    setMotionDetection(device: Device, value: boolean): Promise<void>;
    setSoundDetection(device: Device, value: boolean): Promise<void>;
    setPetDetection(device: Device, value: boolean): Promise<void>;
    setRTSPStream(device: Device, value: boolean): Promise<void>;
    setAntiTheftDetection(device: Device, value: boolean): Promise<void>;
    setWatermark(device: Device, value: WatermarkSetting1 | WatermarkSetting2 | WatermarkSetting3 | WatermarkSetting4): Promise<void>;
    enableDevice(device: Device, value: boolean): Promise<void>;
    startDownload(device: Device, path: string, cipher_id: number): Promise<void>;
    cancelDownload(device: Device): Promise<void>;
    startLivestream(device: Device): Promise<void>;
    stopLivestream(device: Device): Promise<void>;
    isLiveStreaming(device: Device): boolean;
    isDownloading(device: Device): boolean;
    quickResponse(device: Device, voice_id: number): Promise<void>;
    lockDevice(device: Device, value: boolean): Promise<void>;
}
