import { IndexedProperty, ISupportedFeatures, Properties, PropertyMetadataBoolean, PropertyMetadataNumeric, PropertyMetadataString } from "./interfaces";
export declare enum DeviceType {
    BATTERY_DOORBELL = 7,
    BATTERY_DOORBELL_2 = 16,
    CAMERA = 1,
    CAMERA2 = 9,
    CAMERA2C = 8,
    CAMERA2C_PRO = 15,
    CAMERA2_PRO = 14,
    CAMERA_E = 4,
    DOORBELL = 5,
    FLOODLIGHT = 3,
    INDOOR_CAMERA = 30,
    INDOOR_CAMERA_1080 = 34,
    INDOOR_PT_CAMERA = 31,
    INDOOR_PT_CAMERA_1080 = 35,
    KEYPAD = 11,
    LOCK_ADVANCED = 51,
    LOCK_ADVANCED_NO_FINGER = 53,
    LOCK_BASIC = 50,
    LOCK_BASIC_NO_FINGER = 52,
    MOTION_SENSOR = 10,
    SENSOR = 2,
    SOLO_CAMERA = 32,
    SOLO_CAMERA_PRO = 33,
    STATION = 0
}
export declare enum ParamType {
    CHIME_STATE = 2015,
    DETECT_EXPOSURE = 2023,
    DETECT_MODE = 2004,
    DETECT_MOTION_SENSITIVE = 2005,
    DETECT_SCENARIO = 2028,
    DETECT_SWITCH = 2027,
    DETECT_ZONE = 2006,
    DOORBELL_AUDIO_RECODE = 2042,
    DOORBELL_BRIGHTNESS = 2032,
    DOORBELL_DISTORTION = 2033,
    DOORBELL_HDR = 2029,
    DOORBELL_IR_MODE = 2030,
    DOORBELL_LED_NIGHT_MODE = 2039,
    DOORBELL_MOTION_ADVANCE_OPTION = 2041,
    DOORBELL_MOTION_NOTIFICATION = 2035,
    DOORBELL_NOTIFICATION_JUMP_MODE = 2038,
    DOORBELL_NOTIFICATION_OPEN = 2036,
    DOORBELL_RECORD_QUALITY = 2034,
    DOORBELL_RING_RECORD = 2040,
    DOORBELL_SNOOZE_START_TIME = 2037,
    DOORBELL_VIDEO_QUALITY = 2031,
    NIGHT_VISUAL = 2002,
    OPEN_DEVICE = 2001,
    RINGING_VOLUME = 2022,
    SDCARD = 2010,
    UN_DETECT_ZONE = 2007,
    VOLUME = 2003,
    COMMAND_LED_NIGHT_OPEN = 1026,
    COMMAND_MOTION_DETECTION_PACKAGE = 1016,
    SNOOZE_MODE = 1271,
    WATERMARK_MODE = 1214,
    DEVICE_UPGRADE_NOW = 1134,
    CAMERA_UPGRADE_NOW = 1133,
    DEFAULT_SCHEDULE_MODE = 1257,
    GUARD_MODE = 1224,
    FLOODLIGHT_MANUAL_SWITCH = 1400,
    FLOODLIGHT_MANUAL_BRIGHTNESS = 1401,
    FLOODLIGHT_MOTION_BRIGHTNESS = 1412,
    FLOODLIGHT_SCHEDULE_BRIGHTNESS = 1413,
    FLOODLIGHT_MOTION_SENSITIVTY = 1272,
    CAMERA_SPEAKER_VOLUME = 1230,
    CAMERA_RECORD_ENABLE_AUDIO = 1366,
    CAMERA_RECORD_RETRIGGER_INTERVAL = 1250,
    CAMERA_RECORD_CLIP_LENGTH = 1249,
    CAMERA_IR_CUT = 1013,
    CAMERA_PIR = 1011,
    CAMERA_WIFI_RSSI = 1142,
    CAMERA_MOTION_ZONES = 1204,
    PUSH_MSG_MODE = 1252,
    PRIVATE_MODE = 99904,
    CUSTOM_RTSP_URL = 999991
}
export declare enum AlarmMode {
    AWAY = 0,
    HOME = 1,
    DISARMED = 63
}
export declare enum GuardMode {
    UNKNOWN = -1,
    AWAY = 0,
    HOME = 1,
    DISARMED = 63,
    SCHEDULE = 2,
    GEO = 47,
    CUSTOM1 = 3,
    CUSTOM2 = 4,
    CUSTOM3 = 5,
    OFF = 6
}
export declare enum ResponseErrorCode {
    CODE_CONNECT_ERROR = 997,
    CODE_NEED_VERIFY_CODE = 26052,
    CODE_NETWORK_ERROR = 998,
    CODE_PHONE_NONE_SUPPORT = 26058,
    CODE_SERVER_ERROR = 999,
    CODE_VERIFY_CODE_ERROR = 26050,
    CODE_VERIFY_CODE_EXPIRED = 26051,
    CODE_VERIFY_CODE_MAX = 26053,
    CODE_VERIFY_CODE_NONE_MATCH = 26054,
    CODE_VERIFY_PASSWORD_ERROR = 26055,
    CODE_WHATEVER_ERROR = 0,
    RESP_ERROR_CODE_SESSION_TIMEOUT = 401
}
export declare enum VerfyCodeTypes {
    TYPE_SMS = 0,
    TYPE_PUSH = 1,
    TYPE_EMAIL = 2
}
export declare enum AuthResult {
    ERROR = -1,
    OK = 0,
    RENEW = 2,
    SEND_VERIFY_CODE = 3
}
export declare enum StorageType {
    NONE = 0,
    LOCAL = 1,
    CLOUD = 2,
    LOCAL_AND_CLOUD = 3
}
export interface EventFilterType {
    deviceSN?: string;
    stationSN?: string;
    storageType?: StorageType;
}
export declare enum DeviceEvent {
    MotionDetected = 0,
    PersonDetected = 1,
    PetDetected = 2,
    SoundDetected = 3,
    CryingDetected = 4,
    Ringing = 5
}
export declare enum SupportedFeature {
    Battery = 1,
    MotionDetection = 2,
    PersonDetection = 3,
    SoundDetection = 4,
    CryingDetection = 5,
    PetDetection = 6,
    StatusLED = 7,
    AutoNightVision = 8,
    RTSP = 9,
    AntiTheftDetection = 10,
    Watermarking = 11,
    Livestreaming = 12,
    Locking = 13,
    QuickResponse = 14,
    AudioRecording = 15,
    Speaker = 16,
    Ringing = 17,
    LocalStorage = 18,
    OpenClose = 19,
    RebootHUB = 20
}
export declare const SupportedFeatures: ISupportedFeatures;
export declare enum PropertyName {
    Name = "name",
    Model = "model",
    SerialNumber = "serialNumber",
    HardwareVersion = "hardwareVersion",
    SoftwareVersion = "softwareVersion",
    Type = "type",
    DeviceStationSN = "stationSerialNumber",
    DeviceBattery = "battery",
    DeviceBatteryTemp = "batteryTemperature",
    DeviceBatteryLow = "batteryLow",
    DeviceLastChargingDays = "lastChargingDays",
    DeviceLastChargingTotalEvents = "lastChargingTotalEvents",
    DeviceLastChargingRecordedEvents = "lastChargingRecordedEvents",
    DeviceLastChargingFalseEvents = "lastChargingFalseEvents",
    DeviceBatteryUsageLastWeek = "batteryUsageLastWeek",
    DeviceWifiRSSI = "wifiRSSI",
    DeviceEnabled = "enabled",
    DeviceAntitheftDetection = "antitheftDetection",
    DeviceAutoNightvision = "autoNightvision",
    DeviceStatusLed = "statusLed",
    DeviceMotionDetection = "motionDetection",
    DeviceMotionDetected = "motionDetected",
    DevicePersonDetected = "personDetected",
    DevicePersonName = "personName",
    DeviceRTSPStream = "rtspStream",
    DeviceWatermark = "watermark",
    DevicePictureUrl = "pictureUrl",
    DeviceState = "state",
    DevicePetDetection = "petDetection",
    DevicePetDetected = "petDetected",
    DeviceSoundDetection = "soundDetection",
    DeviceSoundDetected = "soundDetected",
    DeviceCryingDetected = "cryingDetected",
    DeviceSensorOpen = "sensorOpen",
    DeviceSensorChangeTime = "sensorChangeTime",
    DeviceMotionSensorPIREvent = "motionSensorPIREvent",
    DeviceLocked = "locked",
    DeviceRinging = "ringing",
    DeviceLockStatus = "lockStatus",
    StationLANIpAddress = "lanIpAddress",
    StationMacAddress = "macAddress",
    StationGuardMode = "guardMode",
    StationCurrentMode = "currentMode"
}
export declare const DeviceNameProperty: PropertyMetadataString;
export declare const DeviceModelProperty: PropertyMetadataString;
export declare const DeviceSerialNumberProperty: PropertyMetadataString;
export declare const GenericHWVersionProperty: PropertyMetadataString;
export declare const GenericSWVersionProperty: PropertyMetadataString;
export declare const GenericTypeProperty: PropertyMetadataNumeric;
export declare const BaseDeviceProperties: IndexedProperty;
export declare const GenericDeviceProperties: IndexedProperty;
export declare const DeviceBatteryProperty: PropertyMetadataNumeric;
export declare const DeviceBatteryLowMotionSensorProperty: PropertyMetadataBoolean;
export declare const DeviceBatteryLowKeypadProperty: PropertyMetadataBoolean;
export declare const DeviceBatteryLowSensorProperty: PropertyMetadataBoolean;
export declare const DeviceBatteryTempProperty: PropertyMetadataNumeric;
export declare const DeviceAntitheftDetectionProperty: PropertyMetadataBoolean;
export declare const DeviceAutoNightvisionProperty: PropertyMetadataBoolean;
export declare const DeviceWifiRSSIProperty: PropertyMetadataNumeric;
export declare const DeviceWifiRSSILockProperty: PropertyMetadataNumeric;
export declare const DeviceEnabledProperty: PropertyMetadataBoolean;
export declare const DeviceEnabledStandaloneProperty: PropertyMetadataBoolean;
export declare const DeviceStatusLedProperty: PropertyMetadataBoolean;
export declare const DeviceStatusLedIndoorSoloFloodProperty: PropertyMetadataBoolean;
export declare const DeviceStatusLedBatteryDoorbellProperty: PropertyMetadataBoolean;
export declare const DeviceStatusLedDoorbellProperty: PropertyMetadataBoolean;
export declare const DeviceMotionDetectionProperty: PropertyMetadataBoolean;
export declare const DeviceMotionDetectionIndoorSoloFloodProperty: PropertyMetadataBoolean;
export declare const DeviceMotionDetectionDoorbellProperty: PropertyMetadataBoolean;
export declare const DeviceSoundDetectionProperty: PropertyMetadataBoolean;
export declare const DevicePetDetectionProperty: PropertyMetadataBoolean;
export declare const DeviceRTSPStreamProperty: PropertyMetadataBoolean;
export declare const DeviceWatermarkProperty: PropertyMetadataNumeric;
export declare const DeviceWatermarkIndoorFloodProperty: PropertyMetadataNumeric;
export declare const DeviceWatermarkSoloWiredDoorbellProperty: PropertyMetadataNumeric;
export declare const DeviceWatermarkBatteryDoorbellCamera1Property: PropertyMetadataNumeric;
export declare const DeviceStateProperty: PropertyMetadataNumeric;
export declare const DeviceStateLockProperty: PropertyMetadataNumeric;
export declare const DeviceLastChargingDaysProperty: PropertyMetadataNumeric;
export declare const DeviceLastChargingTotalEventsProperty: PropertyMetadataNumeric;
export declare const DeviceLastChargingRecordedEventsProperty: PropertyMetadataNumeric;
export declare const DeviceLastChargingFalseEventsProperty: PropertyMetadataNumeric;
export declare const DeviceBatteryUsageLastWeekProperty: PropertyMetadataNumeric;
export declare const DeviceLockedProperty: PropertyMetadataBoolean;
export declare const DeviceMotionDetectedProperty: PropertyMetadataBoolean;
export declare const DevicePersonDetectedProperty: PropertyMetadataBoolean;
export declare const DevicePetDetectedProperty: PropertyMetadataBoolean;
export declare const DeviceSoundDetectedProperty: PropertyMetadataBoolean;
export declare const DeviceCryingDetectedProperty: PropertyMetadataBoolean;
export declare const DeviceRingingProperty: PropertyMetadataBoolean;
export declare const DeviceSensorOpenProperty: PropertyMetadataBoolean;
export declare const DeviceSensorChangeTimeProperty: PropertyMetadataNumeric;
export declare const DeviceMotionSensorPIREventProperty: PropertyMetadataNumeric;
export declare const DeviceLockStatusProperty: PropertyMetadataNumeric;
export declare const DevicePictureUrlProperty: PropertyMetadataString;
export declare const DeviceProperties: Properties;
export declare const StationNameProperty: PropertyMetadataString;
export declare const StationModelProperty: PropertyMetadataString;
export declare const StationSerialNumberProperty: PropertyMetadataString;
export declare const BaseStationProperties: IndexedProperty;
export declare const StationGuardModeProperty: PropertyMetadataNumeric;
export declare const StationCurrentModeProperty: PropertyMetadataNumeric;
export declare const StationLanIpAddressProperty: PropertyMetadataString;
export declare const StationLanIpAddressStandaloneProperty: PropertyMetadataString;
export declare const StationMacAddressProperty: PropertyMetadataString;
export declare const StationProperties: Properties;
